summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouchstatus.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
commit648ba4a456d3aad2825193ff8f3bd52a875783b5 (patch)
tree0b50d2253a0c85238cc4dcba5c4f949de3f0eb15 /ktouch/src/ktouchstatus.h
parent98a12d05a48814bec3870b9a6d5865475cfa1c95 (diff)
downloadtdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.tar.gz
tdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1212481 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ktouch/src/ktouchstatus.h')
-rw-r--r--ktouch/src/ktouchstatus.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/ktouch/src/ktouchstatus.h b/ktouch/src/ktouchstatus.h
index a3135dc3..72bb6acc 100644
--- a/ktouch/src/ktouchstatus.h
+++ b/ktouch/src/ktouchstatus.h
@@ -22,20 +22,20 @@
/** This is the implementation of the status widget (at the top of the main view).
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
* using the updatetqStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/
-class KTouchtqStatus : public KTouchtqStatusLayout {
+class KTouchStatus : public KTouchStatusLayout {
Q_OBJECT
public:
/// Constructor
- KTouchtqStatus(TQWidget *parent);
+ KTouchStatus(TQWidget *parent);
/// Called when the preferences have changed in the configuration dialog.
void applyPreferences();
/// Sets the new characters text.
void setNewChars(const TQString& newChars);
/// Updates the level LCD and the correctness progress bar
- void updatetqStatus(unsigned int level, double correctness);
+ void updateStatus(unsigned int level, double correctness);
};
#endif // KTOUCHSTATUS_H
@@ -22,20 +22,20 @@
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
- * using the updatetqStatus() member function.
+ * using the updateStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/